// Test program for ledStep() function which is part of railwaydemov4

#define LED1 11        // pin for led1
#define LED2 12        // pin for led2

#define LEDS_OFF 0      // value for state of leds: both leds off
#define LEDS_BLINK 1    // value for state of leds: leds blinking alternating
#define LED_TIMERSETTING 500     // period for led blinking time in ms

int ledState = LEDS_OFF;                 // variable indicating whether leds are blinking or not
int prevledState = LEDS_OFF;             // previous value of ledState
boolean led1Value = LOW;                 // value for state of LED1, LOW or HIGH used for blinking

unsigned long ledTimer = LED_TIMERSETTING;              // variable for timing of the blinking

unsigned long timer;   //timer only used in testing program

void setup() {
  // put your setup code here, to run once:
  // define how outputs are connected to Arduino
  pinMode(LED1, OUTPUT);
  pinMode(LED2, OUTPUT);

  timer = millis();

  Serial.begin(9600);
}

void loop() {
  unsigned long currentTime;

  currentTime = millis();
  if (currentTime - timer < 5000) // blink for 5 sec
  {
    prevledState = ledState;
    ledState = LEDS_BLINK;
  }
  else
  {
    if (currentTime - timer < 7000) // off for 2 next sec.
    {
      prevledState = ledState;
      ledState = LEDS_OFF;
    }
    else
    {
      timer = millis();   //re-initialize timer and start over.
    }
  }

  Serial.print("ledState: "); Serial.println(ledState);

  ledStep();    // call ledStep() to do the work
}

void ledStep()
{
  switch (ledState)
  {
    case LEDS_OFF:
      digitalWrite(LED1, LOW);
      digitalWrite(LED2, LOW);
      break;

    case LEDS_BLINK:
      // when entering for the first time in this state start by switching LED1 on
      // LED2 off else toggle leds after blinking period expired
      if (prevledState != ledState)
      {
        led1Value = HIGH;
        digitalWrite(LED1, led1Value);
        digitalWrite(LED2, !led1Value);
        ledTimer = millis();      // initialize timer
        prevledState = ledState;
      }
      else
      {
        if (millis() - ledTimer >= LED_TIMERSETTING)    // if blinking periode expires
        {
          led1Value = !led1Value;   //toggle led1Value
          digitalWrite(LED1, led1Value);
          digitalWrite(LED2, !led1Value);
          ledTimer = millis();    // re-initialize timer
        }
      }
      break;
  }
}

